"""widebible — Python SDK for WideBible.

Access Bible verses, people, places, cross-references, and study tools
from the WideBible REST API.

Usage::

    from widebible import WideBible

    with WideBible() as client:
        verse = client.get_verse("john", 3, 16)
        print(verse)
"""

from widebible.client import WideBible

__version__ = "0.1.1"

__all__ = [
    "WideBible",
    "__version__",
]
